/*
 * osd.h: A plugin for the Video Disk Recorder
 *
 * See the README file for copyright information and how to reach the author.
 *
 * $Id$
 */

#include <vdr/plugin.h>
#include <vdr/osd.h>
#include "config.h"

class cHideSubtitles : public cOsdObject {
  private:
    cOsd *osd;
    enum modes { 
      move,
      resize,
    };  
    modes mode;
    void DrawBars(void);
  public:
    cHideSubtitles(void);
    ~cHideSubtitles();
    virtual void Show(void);
    virtual eOSState ProcessKey(eKeys Key);
};
