/*
 * i18n.c: Internationalization
 *
 * See the README file for copyright information and how to reach the author.
 *
 * $Id:$
 */

#include "i18n.h"

#if VDRVERSNUM < 10507
const tI18nPhrase Phrases[] = {
// START I18N
// END I18N
  { NULL }
  };
#endif
