/*
 * hidesubtitles.c: A plugin for the Video Disk Recorder
 *
 * See the README file for copyright information and how to reach the author.
 *
 * $Id$
 */

#include <vdr/plugin.h>
#include "config.h"
#include "osd.h"
#include "i18n.h"

static const char *VERSION        = "0.0.2";
static const char *DESCRIPTION    = trNOOP("Draws black boxes over subtiles");
static const char *MAINMENUENTRY  = trNOOP("Hide subtitles");

class cPluginHidesubtitles : public cPlugin {
  private:
    // Add any member variables or functions you may need here.
  public:
    cPluginHidesubtitles(void);
    virtual ~cPluginHidesubtitles();
    virtual const char *Version(void) { return VERSION; }
    virtual const char *Description(void) { return tr(DESCRIPTION); }
    virtual const char *CommandLineHelp(void);
    virtual bool ProcessArgs(int argc, char *argv[]);
    virtual bool Initialize(void);
    virtual bool Start(void);
    virtual void Stop(void);
    virtual void Housekeeping(void);
    virtual void MainThreadHook(void);
    virtual cString Active(void);
    virtual const char *MainMenuEntry(void) { return tr(MAINMENUENTRY); }
    virtual cOsdObject *MainMenuAction(void);
    virtual cMenuSetupPage *SetupMenu(void);
    virtual bool SetupParse(const char *Name, const char *Value);
    virtual bool Service(const char *Id, void *Data = NULL);
    virtual const char **SVDRPHelpPages(void);
    virtual cString SVDRPCommand(const char *Command, const char *Option, int &ReplyCode);
};

cPluginHidesubtitles::cPluginHidesubtitles(void) {
  // Initialize any member variables here.
  // DON'T DO ANYTHING ELSE THAT MAY HAVE SIDE EFFECTS, REQUIRE GLOBAL
  // VDR OBJECTS TO EXIST OR PRODUCE ANY OUTPUT!
}

cPluginHidesubtitles::~cPluginHidesubtitles() {
  // Clean up after yourself!
}

const char *cPluginHidesubtitles::CommandLineHelp(void) {
  // Return a string that describes all known command line options.
  return NULL;
}

bool cPluginHidesubtitles::ProcessArgs(int argc, char *argv[]) {
  // Implement command line argument processing here if applicable.
  return true;
}

bool cPluginHidesubtitles::Initialize(void) {
  // Initialize any background activities the plugin shall perform.
  return true;
}

bool cPluginHidesubtitles::Start(void) {
  // Start any background activities the plugin shall perform.
#if VDRVERSNUM < 10507
  RegisterI18n(Phrases);
#endif
  return true;
}

void cPluginHidesubtitles::Stop(void) {
  // Stop any background activities the plugin shall perform.
}

void cPluginHidesubtitles::Housekeeping(void) {
  // Perform any cleanup or other regular tasks.
}

void cPluginHidesubtitles::MainThreadHook(void) {
  // Perform actions in the context of the main program thread.
  // WARNING: Use with great care - see PLUGINS.html!
}

cString cPluginHidesubtitles::Active(void) {
  // Return a message string if shutdown should be postponed
  return NULL;
}

cOsdObject *cPluginHidesubtitles::MainMenuAction(void) {
  // Perform the action when selected from the main VDR menu.
  return new cHideSubtitles;
}

cMenuSetupPage *cPluginHidesubtitles::SetupMenu(void) {
  // Return a setup menu in case the plugin supports one.
  return NULL;
}

bool cPluginHidesubtitles::SetupParse(const char *Name, const char *Value) {
  // Parse your own setup parameters and store their values.
  return hsc.SetupParse(Name, Value);;
}

bool cPluginHidesubtitles::Service(const char *Id, void *Data) {
  // Handle custom service requests from other plugins
  return false;
}

const char **cPluginHidesubtitles::SVDRPHelpPages(void) {
  // Return help text for SVDRP commands this plugin implements
  return NULL;
}

cString cPluginHidesubtitles::SVDRPCommand(const char *Command, const char *Option, int &ReplyCode) {
  // Process SVDRP commands this plugin implements
  return NULL;
}

VDRPLUGINCREATOR(cPluginHidesubtitles); // Don't touch this!
