/*
 * config.h: A plugin for the Video Disk Recorder
 *
 * See the README file for copyright information and how to reach the author.
 *
 * $Id$
 */

#ifndef _HIDESUBTITLES_CONFIG_H_
#define _HIDESUBTITLES_CONFIG_H_

#define SCREEN_WIDTH 720
#define OSD_Y 360
#define OSD_WIDTH 680
#define OSD_HEIGHT 200
#define BAR_Y 60
#define BAR_WIDTH 580
#define BAR_HEIGHT 40
#define BAR_SPACE 20

class cHideSubtitlesConfig {
  public:
    // variables
    int x;
    int y;
    int width;
    int height;
    int space;
    // member functions
    cHideSubtitlesConfig();
    ~cHideSubtitlesConfig();
    bool SetupParse(const char *Name, const char *Value);
    void Store(void);
};

extern cHideSubtitlesConfig hsc;

#endif
